==> org.eclipse.sapphire.ui.source_0.1.0.201101041550.jar: org/eclipse/sapphire/ui/editor/views/masterdetails/internal/ListPropertyNodeFactory.java <==
/******************************************************************************
 * Copyright (c) 2011 Oracle
 * All rights reserved. This program and the accompanying materials
 * are made available under the terms of the Eclipse Public License v1.0
 * which accompanies this distribution, and is available at
 * http://www.eclipse.org/legal/epl-v10.html
 *
 * Contributors:
 *    Konstantin Komissarchik - initial implementation and ongoing maintenance
 ******************************************************************************/

package org.eclipse.sapphire.ui.editor.views.masterdetails.internal;

import java.util.ArrayList;
import java.util.HashMap;
import java.util.List;
import java.util.Map;

import org.eclipse.sapphire.modeling.IModelElement;
import org.eclipse.sapphire.modeling.ListProperty;
import org.eclipse.sapphire.modeling.ModelElementList;
import org.eclipse.sapphire.ui.SapphireCondition;
import org.eclipse.sapphire.ui.editor.views.masterdetails.MasterDetailsContentNode;

/**
 * @author <a href="mailto:konstantin.komissarchik@oracle.com">Konstantin Komissarchik</a>
 */

public abstract class ListPropertyNodeFactory
{
    private final IModelElement modelElement;
    private final ListProperty listProperty;
    private Map<Object,MasterDetailsContentNode> nodesCache;
    private final SapphireCondition visibleWhenCondition;
    
    public ListPropertyNodeFactory( final IModelElement modelElement,
                                    final ListProperty listProperty,
                                    final SapphireCondition visibleWhenCondition )
    {
        if( modelElement == null )
        {
            throw new IllegalArgumentException();
        }
        
        if( listProperty == null )
        {
            throw new IllegalArgumentException();
        }
        
        this.modelElement = modelElement;
        this.listProperty = listProperty;
        this.nodesCache = null;
        this.visibleWhenCondition = visibleWhenCondition;
    }
    
    public final boolean isVisible()
    {
        if( this.visibleWhenCondition != null )
        {
            return this.visibleWhenCondition.evaluate();
        }
        
        return true;
    }
    
    public ListProperty getListProperty()
    {
        return this.listProperty;
    }
    
    public List<MasterDetailsContentNode> createNodes()
    {
        final Map<Object,MasterDetailsContentNode> newCache = new HashMap<Object,MasterDetailsContentNode>();
        final List<MasterDetailsContentNode> nodes = new ArrayList<MasterDetailsContentNode>();
        final ModelElementList<?> list;
        
        try
        {
            list = (ModelElementList<?>) this.listProperty.invokeGetterMethod( this.modelElement );
        }
        catch( Exception e )
        {
            throw new RuntimeException( e );
        }
        
        for( IModelElement listEntryModelElement : list )
        {
            MasterDetailsContentNode node = ( this.nodesCache != null ? this.nodesCache.get( listEntryModelElement ) : null );
            
            if( node == null )
            {
                node = createNode( listEntryModelElement );
            }
            
            nodes.add( node );
            newCache.put( listEntryModelElement, node );
        }
        
        this.nodesCache = newCache;
        
        return nodes;
    }
    
    protected abstract MasterDetailsContentNode createNode( final IModelElement listElement );
}

==> org.eclipse.sapphire.ui.source_0.2.1.201103081041.jar: org/eclipse/sapphire/ui/editor/views/masterdetails/internal/ListPropertyNodeFactory.java <==
/******************************************************************************
 * Copyright (c) 2011 Oracle
 * All rights reserved. This program and the accompanying materials
 * are made available under the terms of the Eclipse Public License v1.0
 * which accompanies this distribution, and is available at
 * http://www.eclipse.org/legal/epl-v10.html
 *
 * Contributors:
 *    Konstantin Komissarchik - initial implementation and ongoing maintenance
 ******************************************************************************/

package org.eclipse.sapphire.ui.editor.views.masterdetails.internal;

import java.util.ArrayList;
import java.util.HashMap;
import java.util.List;
import java.util.Map;

import org.eclipse.sapphire.modeling.IModelElement;
import org.eclipse.sapphire.modeling.ListProperty;
import org.eclipse.sapphire.modeling.ModelElementList;
import org.eclipse.sapphire.ui.SapphireCondition;
import org.eclipse.sapphire.ui.editor.views.masterdetails.MasterDetailsContentNode;

/**
 * @author <a href="mailto:konstantin.komissarchik@oracle.com">Konstantin Komissarchik</a>
 */

public abstract class ListPropertyNodeFactory
{
    private final IModelElement modelElement;
    private final ListProperty listProperty;
    private Map<Object,MasterDetailsContentNode> nodesCache;
    private final SapphireCondition visibleWhenCondition;
    
    public ListPropertyNodeFactory( final IModelElement modelElement,
                                    final ListProperty listProperty,
                                    final SapphireCondition visibleWhenCondition )
    {
        if( modelElement == null )
        {
            throw new IllegalArgumentException();
        }
        
        if( listProperty == null )
        {
            throw new IllegalArgumentException();
        }
        
        this.modelElement = modelElement;
        this.listProperty = listProperty;
        this.nodesCache = null;
        this.visibleWhenCondition = visibleWhenCondition;
    }
    
    public final boolean isVisible()
    {
        if( this.visibleWhenCondition != null )
        {
            return this.visibleWhenCondition.getConditionState();
        }
        
        return true;
    }
    
    public ListProperty getListProperty()
    {
        return this.listProperty;
    }
    
    public List<MasterDetailsContentNode> createNodes()
    {
        final Map<Object,MasterDetailsContentNode> newCache = new HashMap<Object,MasterDetailsContentNode>();
        final List<MasterDetailsContentNode> nodes = new ArrayList<MasterDetailsContentNode>();
        final ModelElementList<?> list = this.modelElement.read( this.listProperty );
        
        for( IModelElement listEntryModelElement : list )
        {
            MasterDetailsContentNode node = ( this.nodesCache != null ? this.nodesCache.get( listEntryModelElement ) : null );
            
            if( node == null )
            {
                node = createNode( listEntryModelElement );
            }
            
            nodes.add( node );
            newCache.put( listEntryModelElement, node );
        }
        
        this.nodesCache = newCache;
        
        return nodes;
    }
    
    protected abstract MasterDetailsContentNode createNode( final IModelElement listElement );
}
